@@ -5,7 +5,7 @@
 ** in the input file. */
 #include "first.h"
 #include <stdio.h>
-#line 5 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 5 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 
 #include "first.h"
 #include "base.h"
@@ -26,25 +26,35 @@ static data_config * configparser_get_data_config(const array *a, const char *k,
   return (data_config *)array_get_data_unset(a, k, klen);
 }
 
+__attribute_noinline__
+static void configparser_push_data_config_list(data_config_list *v, data_config *dc) {
+    if (v->size == v->used) {
+        ck_realloc_u32((void **)&v->data, v->size, 4, sizeof(*v->data));
+        v->size += 4;
+    }
+    v->data[v->used++] = dc;
+}
+
 static void configparser_push(config_t *ctx, data_config *dc, int isnew) {
   if (isnew) {
     dc->context_ndx = ctx->all_configs->used;
     force_assert(dc->context_ndx > ctx->current->context_ndx);
     array_insert_unique(ctx->all_configs, (data_unset *)dc);
     dc->parent = ctx->current;
-    vector_config_weak_push(&dc->parent->children, dc);
+    configparser_push_data_config_list(&dc->parent->children, dc);
   }
   if (ctx->configs_stack.used > 0 && ctx->current->context_ndx == 0) {
     fprintf(stderr, "Cannot use conditionals inside a global { ... } block\n");
     exit(-1);
   }
-  vector_config_weak_push(&ctx->configs_stack, ctx->current);
+  configparser_push_data_config_list(&ctx->configs_stack, ctx->current);
   ctx->current = dc;
 }
 
 static data_config *configparser_pop(config_t *ctx) {
   data_config *old = ctx->current;
-  ctx->current = vector_config_weak_pop(&ctx->configs_stack);
+  force_assert(ctx->configs_stack.used);
+  ctx->current = ctx->configs_stack.data[--ctx->configs_stack.used];
   force_assert(old && ctx->current);
   return old;
 }
@@ -341,7 +351,7 @@ configparser_parse_else_condition(config_t * const ctx)
 }
 
 
-#line 345 "./configparser.c"
+#line 355 "./configparser.c"
 /* Next is all token values, in a form suitable for use by makeheaders.
 ** This section will be null unless lemon is run with the -m switch.
 */
@@ -771,45 +781,45 @@ static void yy_destructor(YYCODETYPE yymajor, YYMINORTYPE *yypminor){
     case 26:
     case 27:
     case 28:
-#line 377 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 387 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 { buffer_free((yypminor->yy0)); }
-#line 776 "./configparser.c"
-      break;
-    case 38:
-#line 368 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
-{ if ((yypminor->yy59)) (yypminor->yy59)->fn->free((yypminor->yy59)); }
-#line 781 "./configparser.c"
-      break;
-    case 39:
-#line 369 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
-{ if ((yypminor->yy59)) (yypminor->yy59)->fn->free((yypminor->yy59)); }
 #line 786 "./configparser.c"
       break;
-    case 40:
-#line 370 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+    case 38:
+#line 378 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 { if ((yypminor->yy59)) (yypminor->yy59)->fn->free((yypminor->yy59)); }
 #line 791 "./configparser.c"
       break;
-    case 43:
-#line 371 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
-{ array_free((yypminor->yy38)); }
+    case 39:
+#line 379 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
+{ if ((yypminor->yy59)) (yypminor->yy59)->fn->free((yypminor->yy59)); }
 #line 796 "./configparser.c"
       break;
-    case 44:
-#line 372 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
-{ array_free((yypminor->yy38)); }
+    case 40:
+#line 380 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
+{ if ((yypminor->yy59)) (yypminor->yy59)->fn->free((yypminor->yy59)); }
 #line 801 "./configparser.c"
       break;
-    case 45:
-#line 373 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
-{ buffer_free((yypminor->yy9)); }
+    case 43:
+#line 381 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
+{ array_free((yypminor->yy38)); }
 #line 806 "./configparser.c"
       break;
-    case 46:
-#line 374 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
-{ buffer_free((yypminor->yy9)); }
+    case 44:
+#line 382 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
+{ array_free((yypminor->yy38)); }
 #line 811 "./configparser.c"
       break;
+    case 45:
+#line 383 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
+{ buffer_free((yypminor->yy9)); }
+#line 816 "./configparser.c"
+      break;
+    case 46:
+#line 384 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
+{ buffer_free((yypminor->yy9)); }
+#line 821 "./configparser.c"
+      break;
     default:  break;   /* If no destructor action specified: do nothing */
   }
 }
@@ -1087,9 +1097,9 @@ static void yy_reduce(
         /* No destructor defined for global */
         break;
       case 5:
-#line 350 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 360 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 { yymsp[-1].minor.yy18 = NULL; }
-#line 1092 "./configparser.c"
+#line 1102 "./configparser.c"
   yy_destructor(1,&yymsp[0].minor);
         break;
       case 6:
@@ -1102,7 +1112,7 @@ static void yy_reduce(
   yy_destructor(1,&yymsp[0].minor);
         break;
       case 9:
-#line 379 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 389 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   if (ctx->ok) {
     buffer_copy_buffer(&yymsp[0].minor.yy59->key, yymsp[-2].minor.yy9);
@@ -1126,11 +1136,11 @@ static void yy_reduce(
   if (yymsp[0].minor.yy59) yymsp[0].minor.yy59->fn->free(yymsp[0].minor.yy59);
   yymsp[0].minor.yy59 = NULL;
 }
-#line 1129 "./configparser.c"
+#line 1139 "./configparser.c"
   yy_destructor(2,&yymsp[-1].minor);
         break;
       case 10:
-#line 403 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 413 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   if (ctx->ok) {
     if (strncmp(yymsp[-2].minor.yy9->ptr, "env.", sizeof("env.") - 1) == 0) {
@@ -1149,11 +1159,11 @@ static void yy_reduce(
   if (yymsp[0].minor.yy59) yymsp[0].minor.yy59->fn->free(yymsp[0].minor.yy59);
   yymsp[0].minor.yy59 = NULL;
 }
-#line 1152 "./configparser.c"
+#line 1162 "./configparser.c"
   yy_destructor(3,&yymsp[-1].minor);
         break;
       case 11:
-#line 422 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 432 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   if (ctx->ok) {
     array *vars = ctx->current->value;
@@ -1184,11 +1194,11 @@ static void yy_reduce(
   if (yymsp[0].minor.yy59) yymsp[0].minor.yy59->fn->free(yymsp[0].minor.yy59);
   yymsp[0].minor.yy59 = NULL;
 }
-#line 1187 "./configparser.c"
+#line 1197 "./configparser.c"
   yy_destructor(4,&yymsp[-1].minor);
         break;
       case 12:
-#line 453 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 463 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   if (strchr(yymsp[0].minor.yy0->ptr, '.') == NULL) {
     buffer_copy_string((yygotominor.yy9 = buffer_init()), "var.");
@@ -1200,10 +1210,10 @@ static void yy_reduce(
   buffer_free(yymsp[0].minor.yy0);
   yymsp[0].minor.yy0 = NULL;
 }
-#line 1203 "./configparser.c"
+#line 1213 "./configparser.c"
         break;
       case 13:
-#line 465 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 475 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy59 = NULL;
   if (ctx->ok) {
@@ -1218,19 +1228,19 @@ static void yy_reduce(
   if (yymsp[0].minor.yy59) yymsp[0].minor.yy59->fn->free(yymsp[0].minor.yy59);
   yymsp[0].minor.yy59 = NULL;
 }
-#line 1221 "./configparser.c"
+#line 1231 "./configparser.c"
   yy_destructor(6,&yymsp[-1].minor);
         break;
       case 14:
-#line 480 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 490 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy59 = yymsp[0].minor.yy59;
   yymsp[0].minor.yy59 = NULL;
 }
-#line 1230 "./configparser.c"
+#line 1240 "./configparser.c"
         break;
       case 15:
-#line 485 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 495 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy59 = NULL;
   if (ctx->ok) {
@@ -1255,10 +1265,10 @@ static void yy_reduce(
   buffer_free(yymsp[0].minor.yy9);
   yymsp[0].minor.yy9 = NULL;
 }
-#line 1258 "./configparser.c"
+#line 1268 "./configparser.c"
         break;
       case 16:
-#line 510 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 520 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy59 = (data_unset *)array_data_string_init();
   /* assumes array_data_string_init() result does not need swap, buffer_free()*/
@@ -1266,10 +1276,10 @@ static void yy_reduce(
   free(yymsp[0].minor.yy0);
   yymsp[0].minor.yy0 = NULL;
 }
-#line 1269 "./configparser.c"
+#line 1279 "./configparser.c"
         break;
       case 17:
-#line 518 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 528 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   char *endptr;
   yygotominor.yy59 = (data_unset *)array_data_integer_init();
@@ -1284,10 +1294,10 @@ static void yy_reduce(
   buffer_free(yymsp[0].minor.yy0);
   yymsp[0].minor.yy0 = NULL;
 }
-#line 1287 "./configparser.c"
+#line 1297 "./configparser.c"
         break;
       case 18:
-#line 532 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 542 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy59 = (data_unset *)array_data_array_init();
   /* assumes array_data_array_init() result does not need swap, array_free() */
@@ -1295,29 +1305,29 @@ static void yy_reduce(
   free(yymsp[0].minor.yy38);
   yymsp[0].minor.yy38 = NULL;
 }
-#line 1298 "./configparser.c"
+#line 1308 "./configparser.c"
         break;
       case 19:
-#line 539 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 549 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy38 = array_init(8);
 }
-#line 1305 "./configparser.c"
+#line 1315 "./configparser.c"
   yy_destructor(9,&yymsp[-1].minor);
   yy_destructor(10,&yymsp[0].minor);
         break;
       case 20:
-#line 542 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 552 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy38 = yymsp[-1].minor.yy38;
   yymsp[-1].minor.yy38 = NULL;
 }
-#line 1315 "./configparser.c"
+#line 1325 "./configparser.c"
   yy_destructor(9,&yymsp[-2].minor);
   yy_destructor(10,&yymsp[0].minor);
         break;
       case 21:
-#line 547 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 557 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy38 = NULL;
   if (ctx->ok) {
@@ -1339,20 +1349,20 @@ static void yy_reduce(
   if (yymsp[0].minor.yy59) yymsp[0].minor.yy59->fn->free(yymsp[0].minor.yy59);
   yymsp[0].minor.yy59 = NULL;
 }
-#line 1342 "./configparser.c"
+#line 1352 "./configparser.c"
   yy_destructor(11,&yymsp[-1].minor);
         break;
       case 22:
-#line 569 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 579 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy38 = yymsp[-1].minor.yy38;
   yymsp[-1].minor.yy38 = NULL;
 }
-#line 1351 "./configparser.c"
+#line 1361 "./configparser.c"
   yy_destructor(11,&yymsp[0].minor);
         break;
       case 23:
-#line 574 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 584 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy38 = NULL;
   if (ctx->ok) {
@@ -1363,18 +1373,18 @@ static void yy_reduce(
   if (yymsp[0].minor.yy59) yymsp[0].minor.yy59->fn->free(yymsp[0].minor.yy59);
   yymsp[0].minor.yy59 = NULL;
 }
-#line 1366 "./configparser.c"
+#line 1376 "./configparser.c"
         break;
       case 24:
-#line 585 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 595 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy59 = yymsp[0].minor.yy59;
   yymsp[0].minor.yy59 = NULL;
 }
-#line 1374 "./configparser.c"
+#line 1384 "./configparser.c"
         break;
       case 25:
-#line 589 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 599 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy59 = NULL;
   if (ctx->ok) {
@@ -1388,7 +1398,7 @@ static void yy_reduce(
   buffer_free(yymsp[-2].minor.yy9);
   yymsp[-2].minor.yy9 = NULL;
 }
-#line 1391 "./configparser.c"
+#line 1401 "./configparser.c"
   yy_destructor(12,&yymsp[-1].minor);
         break;
       case 26:
@@ -1397,29 +1407,29 @@ static void yy_reduce(
       case 27:
         break;
       case 28:
-#line 606 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 616 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   data_config *dc;
   dc = configparser_get_data_config(ctx->srv->config_context, CONST_STR_LEN("global"));
   force_assert(dc);
   configparser_push(ctx, dc, 0);
 }
-#line 1407 "./configparser.c"
+#line 1417 "./configparser.c"
   yy_destructor(13,&yymsp[0].minor);
         break;
       case 29:
-#line 613 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 623 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   configparser_pop(ctx);
 }
-#line 1415 "./configparser.c"
+#line 1425 "./configparser.c"
         /* No destructor defined for globalstart */
   yy_destructor(14,&yymsp[-2].minor);
         /* No destructor defined for metalines */
   yy_destructor(15,&yymsp[0].minor);
         break;
       case 30:
-#line 617 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 627 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
@@ -1438,12 +1448,12 @@ static void yy_reduce(
   yymsp[-3].minor.yy18 = NULL;
   yymsp[0].minor.yy18 = NULL;
 }
-#line 1441 "./configparser.c"
+#line 1451 "./configparser.c"
         /* No destructor defined for eols */
   yy_destructor(16,&yymsp[-1].minor);
         break;
       case 31:
-#line 636 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 646 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
@@ -1513,48 +1523,48 @@ static void yy_reduce(
   yymsp[-3].minor.yy18 = NULL;
   yymsp[0].minor.yy18 = NULL;
 }
-#line 1516 "./configparser.c"
+#line 1526 "./configparser.c"
         /* No destructor defined for eols */
   yy_destructor(16,&yymsp[-1].minor);
         break;
       case 32:
-#line 706 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 716 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy18 = yymsp[0].minor.yy18;
   yymsp[0].minor.yy18 = NULL;
 }
-#line 1526 "./configparser.c"
+#line 1536 "./configparser.c"
         break;
       case 33:
-#line 711 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 721 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
     yygotominor.yy18 = configparser_pop(ctx);
   }
 }
-#line 1536 "./configparser.c"
+#line 1546 "./configparser.c"
         /* No destructor defined for context */
   yy_destructor(14,&yymsp[-2].minor);
         /* No destructor defined for metalines */
   yy_destructor(15,&yymsp[0].minor);
         break;
       case 34:
-#line 718 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 728 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
     yygotominor.yy18 = configparser_pop(ctx);
   }
 }
-#line 1550 "./configparser.c"
+#line 1560 "./configparser.c"
         /* No destructor defined for context_else */
   yy_destructor(14,&yymsp[-2].minor);
         /* No destructor defined for metalines */
   yy_destructor(15,&yymsp[0].minor);
         break;
       case 35:
-#line 725 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 735 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
 
   if (ctx->ok && yymsp[0].minor.yy59->type != TYPE_STRING) {
@@ -1570,73 +1580,73 @@ static void yy_reduce(
   yymsp[-5].minor.yy0 = NULL;
   buffer_free(yymsp[-3].minor.yy9);
   yymsp[-3].minor.yy9 = NULL;
-  yymsp[0].minor.yy59->fn->free(yymsp[0].minor.yy59);
+  if (yymsp[0].minor.yy59) yymsp[0].minor.yy59->fn->free(yymsp[0].minor.yy59);
   yymsp[0].minor.yy59 = NULL;
 }
-#line 1576 "./configparser.c"
+#line 1586 "./configparser.c"
   yy_destructor(17,&yymsp[-6].minor);
   yy_destructor(19,&yymsp[-4].minor);
   yy_destructor(20,&yymsp[-2].minor);
         break;
       case 36:
-#line 744 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 754 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   if (ctx->ok) {
     configparser_parse_else_condition(ctx);
   }
 }
-#line 1588 "./configparser.c"
+#line 1598 "./configparser.c"
         break;
       case 37:
-#line 750 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 760 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_EQ;
 }
-#line 1595 "./configparser.c"
+#line 1605 "./configparser.c"
   yy_destructor(21,&yymsp[0].minor);
         break;
       case 38:
-#line 753 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 763 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_MATCH;
 }
-#line 1603 "./configparser.c"
+#line 1613 "./configparser.c"
   yy_destructor(22,&yymsp[0].minor);
         break;
       case 39:
-#line 756 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 766 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_NE;
 }
-#line 1611 "./configparser.c"
+#line 1621 "./configparser.c"
   yy_destructor(23,&yymsp[0].minor);
         break;
       case 40:
-#line 759 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 769 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_NOMATCH;
 }
-#line 1619 "./configparser.c"
+#line 1629 "./configparser.c"
   yy_destructor(24,&yymsp[0].minor);
         break;
       case 41:
-#line 762 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 772 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_PREFIX;
 }
-#line 1627 "./configparser.c"
+#line 1637 "./configparser.c"
   yy_destructor(25,&yymsp[0].minor);
         break;
       case 42:
-#line 765 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 775 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy69 = CONFIG_COND_SUFFIX;
 }
-#line 1635 "./configparser.c"
+#line 1645 "./configparser.c"
   yy_destructor(26,&yymsp[0].minor);
         break;
       case 43:
-#line 769 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 779 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   yygotominor.yy9 = NULL;
   if (ctx->ok) {
@@ -1653,10 +1663,10 @@ static void yy_reduce(
   if (yymsp[0].minor.yy59) yymsp[0].minor.yy59->fn->free(yymsp[0].minor.yy59);
   yymsp[0].minor.yy59 = NULL;
 }
-#line 1656 "./configparser.c"
+#line 1666 "./configparser.c"
         break;
       case 44:
-#line 786 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 796 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   if (ctx->ok) {
     if (0 != config_parse_file(ctx->srv, ctx, yymsp[0].minor.yy9->ptr)) {
@@ -1666,11 +1676,11 @@ static void yy_reduce(
   buffer_free(yymsp[0].minor.yy9);
   yymsp[0].minor.yy9 = NULL;
 }
-#line 1669 "./configparser.c"
+#line 1679 "./configparser.c"
   yy_destructor(27,&yymsp[-1].minor);
         break;
       case 45:
-#line 796 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 806 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 {
   if (ctx->ok) {
     if (0 != config_parse_cmd(ctx->srv, ctx, yymsp[0].minor.yy9->ptr)) {
@@ -1680,7 +1690,7 @@ static void yy_reduce(
   buffer_free(yymsp[0].minor.yy9);
   yymsp[0].minor.yy9 = NULL;
 }
-#line 1683 "./configparser.c"
+#line 1693 "./configparser.c"
   yy_destructor(28,&yymsp[-1].minor);
         break;
   };
@@ -1710,11 +1720,11 @@ static void yy_parse_failed(
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will be executed whenever the
   ** parser fails */
-#line 341 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.67-1.i686/src/lighttpd-1.4.67/src/configparser.y"
+#line 351 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.68-1.x86_64/src/lighttpd-1.4.68/src/configparser.y"
 
   ctx->ok = 0;
 
-#line 1717 "./configparser.c"
+#line 1727 "./configparser.c"
   configparserARG_STORE; /* Suppress warning about unused %extra_argument variable */
 }
 
