@@ -1,13 +1,11 @@
 #include "first.h"
 
-#include "fdevent_impl.h"
 #include "fdevent.h"
 #include "buffer.h"
 #include "log.h"
 
 #include <sys/types.h>
 #include "sys-socket.h"
-#include "sys-time.h"
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -19,6 +17,7 @@
 #include <sys/stat.h>   /* _S_IREAD _S_IWRITE */
 #include <io.h>
 #include <share.h>      /* _SH_DENYRW */
+#include <winsock2.h>
 #endif
 
 #ifdef SOCK_CLOEXEC
@@ -28,137 +27,8 @@ static int use_sock_cloexec;
 static int use_sock_nonblock;
 #endif
 
-int fdevent_config(const char **event_handler_name, log_error_st *errh) {
-	static const struct ev_map { fdevent_handler_t et; const char *name; } event_handlers[] =
-	{
-		/* - epoll is most reliable
-		 * - select works everywhere
-		 */
-#ifdef FDEVENT_USE_LINUX_EPOLL
-		{ FDEVENT_HANDLER_LINUX_SYSEPOLL, "linux-sysepoll" },
-		{ FDEVENT_HANDLER_LINUX_SYSEPOLL, "epoll" },
-#endif
-#ifdef FDEVENT_USE_SOLARIS_PORT
-		{ FDEVENT_HANDLER_SOLARIS_PORT,   "solaris-eventports" },
-#endif
-#ifdef FDEVENT_USE_SOLARIS_DEVPOLL
-		{ FDEVENT_HANDLER_SOLARIS_DEVPOLL,"solaris-devpoll" },
-#endif
-#ifdef FDEVENT_USE_FREEBSD_KQUEUE
-		{ FDEVENT_HANDLER_FREEBSD_KQUEUE, "freebsd-kqueue" },
-		{ FDEVENT_HANDLER_FREEBSD_KQUEUE, "kqueue" },
-#endif
-#ifdef FDEVENT_USE_POLL
-		{ FDEVENT_HANDLER_POLL,           "poll" },
-#endif
-#ifdef FDEVENT_USE_SELECT
-		{ FDEVENT_HANDLER_SELECT,         "select" },
-#endif
-#ifdef FDEVENT_USE_LIBEV
-		{ FDEVENT_HANDLER_LIBEV,          "libev" },
-#endif
-		{ FDEVENT_HANDLER_UNSET,          NULL }
-	};
-
-	const char * event_handler = *event_handler_name;
-	fdevent_handler_t et = FDEVENT_HANDLER_UNSET;
-
-#ifndef FDEVENT_USE_LIBEV
-	if (NULL != event_handler && 0 == strcmp(event_handler, "libev"))
-		event_handler = NULL;
-#endif
-#ifdef FDEVENT_USE_POLL
-	if (NULL != event_handler && 0 == strcmp(event_handler, "select"))
-		event_handler = "poll";
-#endif
-
-	if (NULL == event_handler) {
-		/* choose a good default
-		 *
-		 * the event_handler list is sorted by 'goodness'
-		 * taking the first available should be the best solution
-		 */
-		et = event_handlers[0].et;
-		*event_handler_name = event_handlers[0].name;
-
-		if (FDEVENT_HANDLER_UNSET == et) {
-			log_error(errh, __FILE__, __LINE__,
-			  "sorry, there is no event handler for this system");
-
-			return -1;
-		}
-	} else {
-		/*
-		 * User override
-		 */
-
-		for (uint32_t i = 0; event_handlers[i].name; ++i) {
-			if (0 == strcmp(event_handlers[i].name, event_handler)) {
-				et = event_handlers[i].et;
-				break;
-			}
-		}
-
-		if (FDEVENT_HANDLER_UNSET == et) {
-			log_error(errh, __FILE__, __LINE__,
-			  "the selected event-handler in unknown or not supported: %s",
-			  event_handler);
-			return -1;
-		}
-	}
-
-	return et;
-}
-
-const char * fdevent_show_event_handlers(void) {
-    return
-      "\nEvent Handlers:\n\n"
-#ifdef FDEVENT_USE_SELECT
-      "\t+ select (generic)\n"
-#else
-      "\t- select (generic)\n"
-#endif
-#ifdef FDEVENT_USE_POLL
-      "\t+ poll (Unix)\n"
-#else
-      "\t- poll (Unix)\n"
-#endif
-#ifdef FDEVENT_USE_LINUX_EPOLL
-      "\t+ epoll (Linux)\n"
-#else
-      "\t- epoll (Linux)\n"
-#endif
-#ifdef FDEVENT_USE_SOLARIS_DEVPOLL
-      "\t+ /dev/poll (Solaris)\n"
-#else
-      "\t- /dev/poll (Solaris)\n"
-#endif
-#ifdef FDEVENT_USE_SOLARIS_PORT
-      "\t+ eventports (Solaris)\n"
-#else
-      "\t- eventports (Solaris)\n"
-#endif
-#ifdef FDEVENT_USE_FREEBSD_KQUEUE
-      "\t+ kqueue (FreeBSD)\n"
-#else
-      "\t- kqueue (FreeBSD)\n"
-#endif
-#ifdef FDEVENT_USE_LIBEV
-      "\t+ libev (generic)\n"
-#else
-      "\t- libev (generic)\n"
-#endif
-      ;
-}
-
-fdevents * fdevent_init(const char *event_handler, int *max_fds, int *cur_fds, log_error_st *errh) {
-	fdevents *ev;
-	uint32_t maxfds = (0 != *max_fds)
-	  ? (uint32_t)*max_fds
-	  : 4096;
-	int type = fdevent_config(&event_handler, errh);
-	if (type <= 0) return NULL;
-
+void fdevent_socket_nb_cloexec_init (void)
+{
       #ifdef SOCK_CLOEXEC
 	/* Test if SOCK_CLOEXEC is supported by kernel.
 	 * Linux kernels < 2.6.27 might return EINVAL if SOCK_CLOEXEC used
@@ -182,281 +52,6 @@ fdevents * fdevent_init(const char *event_handler, int *max_fds, int *cur_fds, l
 		close(fd);
 	}
       #endif
-
-      #ifdef FDEVENT_USE_SELECT
-	/* select limits itself
-	 * as it is a hard limit and will lead to a segfault we add some safety
-	 * */
-	if (type == FDEVENT_HANDLER_SELECT) {
-		if (maxfds > (uint32_t)FD_SETSIZE - 200)
-		    maxfds = (uint32_t)FD_SETSIZE - 200;
-	}
-      #endif
-	*max_fds = (int)maxfds;
-	++maxfds; /*(+1 for event-handler fd)*/
-
-	ev = calloc(1, sizeof(*ev));
-	force_assert(NULL != ev);
-	ev->errh = errh;
-	ev->cur_fds = cur_fds;
-	ev->event_handler = event_handler;
-	ev->fdarray = calloc(maxfds, sizeof(*ev->fdarray));
-	if (NULL == ev->fdarray) {
-		log_error(ev->errh, __FILE__, __LINE__,
-		  "server.max-fds too large? (%u)", maxfds-1);
-		free(ev);
-		return NULL;
-	}
-	ev->maxfds = maxfds;
-
-	switch(type) {
-	#ifdef FDEVENT_USE_POLL
-	case FDEVENT_HANDLER_POLL:
-		if (0 == fdevent_poll_init(ev)) return ev;
-		break;
-	#endif
-	#ifdef FDEVENT_USE_SELECT
-	case FDEVENT_HANDLER_SELECT:
-		if (0 == fdevent_select_init(ev)) return ev;
-		break;
-	#endif
-	#ifdef FDEVENT_USE_LINUX_EPOLL
-	case FDEVENT_HANDLER_LINUX_SYSEPOLL:
-		if (0 == fdevent_linux_sysepoll_init(ev)) return ev;
-		break;
-	#endif
-	#ifdef FDEVENT_USE_SOLARIS_DEVPOLL
-	case FDEVENT_HANDLER_SOLARIS_DEVPOLL:
-		if (0 == fdevent_solaris_devpoll_init(ev)) return ev;
-		break;
-	#endif
-	#ifdef FDEVENT_USE_SOLARIS_PORT
-	case FDEVENT_HANDLER_SOLARIS_PORT:
-		if (0 == fdevent_solaris_port_init(ev)) return ev;
-		break;
-	#endif
-	#ifdef FDEVENT_USE_FREEBSD_KQUEUE
-	case FDEVENT_HANDLER_FREEBSD_KQUEUE:
-		if (0 == fdevent_freebsd_kqueue_init(ev)) return ev;
-		break;
-	#endif
-	#ifdef FDEVENT_USE_LIBEV
-	case FDEVENT_HANDLER_LIBEV:
-		if (0 == fdevent_libev_init(ev)) return ev;
-		break;
-	#endif
-	/*case FDEVENT_HANDLER_UNSET:*/
-	default:
-		break;
-	}
-
-	free(ev->fdarray);
-	free(ev);
-
-	log_error(errh, __FILE__, __LINE__,
-	  "event-handler failed: %s; "
-	  "try to set server.event-handler = \"poll\" or \"select\"",
-	  event_handler);
-	return NULL;
-}
-
-void fdevent_free(fdevents *ev) {
-	if (!ev) return;
-
-	if (ev->free) ev->free(ev);
-
-	for (uint32_t i = 0; i < ev->maxfds; ++i) {
-		/* (fdevent_sched_run() should already have been run,
-		 *  but take reasonable precautions anyway) */
-		if (ev->fdarray[i])
-			free((fdnode *)((uintptr_t)ev->fdarray[i] & ~0x3));
-	}
-
-	free(ev->fdarray);
-	free(ev);
-}
-
-int fdevent_reset(fdevents *ev) {
-	int rc = (NULL != ev->reset) ? ev->reset(ev) : 0;
-	if (-1 == rc) {
-		log_error(ev->errh, __FILE__, __LINE__,
-		  "event-handler failed: %s; "
-		  "try to set server.event-handler = \"poll\" or \"select\"",
-		  ev->event_handler ? ev->event_handler : "");
-	}
-	return rc;
-}
-
-__attribute_malloc__
-__attribute_returns_nonnull__
-static fdnode *fdnode_init(void) {
-	fdnode * const restrict fdn = calloc(1, sizeof(fdnode));
-	force_assert(NULL != fdn);
-	return fdn;
-}
-
-static void fdnode_free(fdnode *fdn) {
-	free(fdn);
-}
-
-fdnode * fdevent_register(fdevents *ev, int fd, fdevent_handler handler, void *ctx) {
-	fdnode *fdn  = ev->fdarray[fd] = fdnode_init();
-	fdn->handler = handler;
-	fdn->fd      = fd;
-	fdn->ctx     = ctx;
-	fdn->events  = 0;
-	fdn->fde_ndx = -1;
-      #ifdef FDEVENT_USE_LIBEV
-	fdn->handler_ctx = NULL;
-      #endif
-	return fdn;
-}
-
-void fdevent_unregister(fdevents *ev, int fd) {
-	fdnode *fdn = ev->fdarray[fd];
-	if ((uintptr_t)fdn & 0x3) return; /*(should not happen)*/
-	ev->fdarray[fd] = NULL;
-	fdnode_free(fdn);
-}
-
-void fdevent_sched_close(fdevents *ev, int fd, int issock) {
-	fdnode *fdn = ev->fdarray[fd];
-	if ((uintptr_t)fdn & 0x3) return;
-	ev->fdarray[fd] = (fdnode *)((uintptr_t)fdn | (issock ? 0x1 : 0x2));
-	fdn->handler = (fdevent_handler)NULL;
-	fdn->ctx = ev->pendclose;
-	ev->pendclose = fdn;
-}
-
-static void fdevent_sched_run(fdevents *ev) {
-	for (fdnode *fdn = ev->pendclose; fdn; ) {
-		int fd, rc;
-		fdnode *fdn_tmp;
-	      #ifdef _WIN32
-		rc = (uintptr_t)fdn & 0x3;
-	      #endif
-		fdn = (fdnode *)((uintptr_t)fdn & ~0x3);
-		fd = fdn->fd;
-	      #ifdef _WIN32
-		if (rc == 0x1) {
-			rc = closesocket(fd);
-		}
-		else if (rc == 0x2) {
-			rc = close(fd);
-		}
-	      #else
-		rc = close(fd);
-	      #endif
-
-		if (0 != rc) {
-			log_perror(ev->errh, __FILE__, __LINE__, "close failed %d", fd);
-		}
-		else {
-			--(*ev->cur_fds);
-		}
-
-		fdn_tmp = fdn;
-		fdn = (fdnode *)fdn->ctx; /* next */
-		/*(fdevent_unregister)*/
-		fdnode_free(fdn_tmp);
-		ev->fdarray[fd] = NULL;
-	}
-	ev->pendclose = NULL;
-}
-
-__attribute_cold__
-__attribute_noinline__
-static int fdevent_fdnode_event_unsetter_retry(fdevents *ev, fdnode *fdn) {
-    do {
-        switch (errno) {
-         #ifdef EWOULDBLOCK
-         #if EAGAIN != EWOULDBLOCK
-          case EWOULDBLOCK:
-         #endif
-         #endif
-          case EAGAIN:
-          case EINTR:
-            /* temporary error; retry */
-            break;
-          /*case ENOMEM:*/
-          default:
-            /* unrecoverable error; might leak fd */
-            log_perror(ev->errh, __FILE__, __LINE__,
-              "fdevent event_del failed on fd %d", fdn->fd);
-            return 0;
-        }
-    } while (0 != ev->event_del(ev, fdn));
-    return 1;
-}
-
-static void fdevent_fdnode_event_unsetter(fdevents *ev, fdnode *fdn) {
-    if (-1 == fdn->fde_ndx) return;
-    if (0 != ev->event_del(ev, fdn))
-        fdevent_fdnode_event_unsetter_retry(ev, fdn);
-    fdn->fde_ndx = -1;
-    fdn->events = 0;
-}
-
-__attribute_cold__
-__attribute_noinline__
-static int fdevent_fdnode_event_setter_retry(fdevents *ev, fdnode *fdn, int events) {
-    do {
-        switch (errno) {
-         #ifdef EWOULDBLOCK
-         #if EAGAIN != EWOULDBLOCK
-          case EWOULDBLOCK:
-         #endif
-         #endif
-          case EAGAIN:
-          case EINTR:
-            /* temporary error; retry */
-            break;
-          /*case ENOMEM:*/
-          default:
-            /* unrecoverable error */
-            log_perror(ev->errh, __FILE__, __LINE__,
-              "fdevent event_set failed on fd %d", fdn->fd);
-            return 0;
-        }
-    } while (0 != ev->event_set(ev, fdn, events));
-    return 1;
-}
-
-static void fdevent_fdnode_event_setter(fdevents *ev, fdnode *fdn, int events) {
-    /*(Note: skips registering with kernel if initial events is 0,
-     * so caller should pass non-zero events for initial registration.
-     * If never registered due to never being called with non-zero events,
-     * then FDEVENT_HUP or FDEVENT_ERR will never be returned.) */
-    if (fdn->events == events) return;/*(no change; nothing to do)*/
-
-    if (0 == ev->event_set(ev, fdn, events)
-        || fdevent_fdnode_event_setter_retry(ev, fdn, events))
-        fdn->events = events;
-}
-
-void fdevent_fdnode_event_del(fdevents *ev, fdnode *fdn) {
-    if (NULL != fdn) fdevent_fdnode_event_unsetter(ev, fdn);
-}
-
-void fdevent_fdnode_event_set(fdevents *ev, fdnode *fdn, int events) {
-    if (NULL != fdn) fdevent_fdnode_event_setter(ev, fdn, events);
-}
-
-void fdevent_fdnode_event_add(fdevents *ev, fdnode *fdn, int event) {
-    if (NULL != fdn) fdevent_fdnode_event_setter(ev, fdn, (fdn->events|event));
-}
-
-void fdevent_fdnode_event_clr(fdevents *ev, fdnode *fdn, int event) {
-    if (NULL != fdn) fdevent_fdnode_event_setter(ev, fdn, (fdn->events&~event));
-}
-
-int fdevent_poll(fdevents *ev, int timeout_ms) {
-    int n = ev->poll(ev, timeout_ms);
-    if (n >= 0)
-        fdevent_sched_run(ev);
-    else if (errno != EINTR)
-        log_perror(ev->errh, __FILE__, __LINE__, "fdevent_poll failed");
-    return n;
 }
 
 void fdevent_setfd_cloexec(int fd) {
@@ -576,6 +171,10 @@ int fdevent_dup_cloexec (int fd) {
 #endif
 
 int fdevent_open_cloexec(const char *pathname, int symlinks, int flags, mode_t mode) {
+#ifdef __CYGWIN__ /* broken in current cygwin; fixed in cygwin test */
+#undef  O_NOFOLLOW
+#define O_NOFOLLOW 0
+#endif
 	if (!symlinks) flags |= O_NOFOLLOW;
 #ifdef O_CLOEXEC
 	return open(pathname, flags | O_CLOEXEC | FDEVENT_O_FLAGS, mode);
@@ -593,6 +192,8 @@ int fdevent_open_cloexec(const char *pathname, int symlinks, int flags, mode_t m
 int fdevent_open_devnull(void) {
   #if defined(_WIN32)
     return fdevent_open_cloexec("nul", 0, O_RDWR, 0);
+  #elif defined(__sun) /* /dev/null is a symlink on Illumos */
+    return fdevent_open_cloexec("/dev/null", 1, O_RDWR, 0);
   #else
     return fdevent_open_cloexec("/dev/null", 0, O_RDWR, 0);
   #endif
@@ -947,7 +548,7 @@ int fdevent_is_tcp_half_closed(int fd) {
     return (0 == getsockopt(fd, IPPROTO_TCP, TCP_CONNECTION_INFO, &tcpi, &tlen)
             && tcpi.tcpi_state == TCPS_CLOSE_WAIT);
   #elif defined(TCP_INFO) && defined(TCPS_CLOSE_WAIT)
-    /* FreeBSD, NetBSD (not present in OpenBSD or DragonFlyBSD) */
+    /* FreeBSD, NetBSD, OpenBSD (not present in DragonFlyBSD) */
     struct tcp_info tcpi;
     socklen_t tlen = sizeof(tcpi);
     return (0 == getsockopt(fd, IPPROTO_TCP, TCP_INFO, &tcpi, &tlen)
